@@ -1,14 +1,12 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Optional, Type
+from typing import Optional, Type
 from uuid import UUID
 
 from sila2.framework.abc.message_mappable import MessageMappable
 from sila2.framework.abc.named_data_node import NamedDataNode
-
-if TYPE_CHECKING:
-    from sila2.pb2_stubs import SiLAFramework_pb2
-    from sila2.pb2_stubs.SiLAFramework_pb2 import CommandExecutionUUID as SilaCommandExecutionUUID
+from sila2.framework.pb2 import SiLAFramework_pb2
+from sila2.framework.pb2.SiLAFramework_pb2 import CommandExecutionUUID as SilaCommandExecutionUUID
 
 
 class CommandExecutionUUID(MessageMappable):
