@@ -3,16 +3,14 @@ from __future__ import annotations
 from dataclasses import dataclass
 from datetime import timedelta
 from enum import Enum
-from typing import TYPE_CHECKING, Optional, Type
+from typing import Optional, Type
 
 from sila2.framework.abc.message_mappable import MessageMappable
 from sila2.framework.abc.named_data_node import NamedDataNode
 from sila2.framework.command.duration import Duration
 from sila2.framework.data_types.real import Real
-
-if TYPE_CHECKING:
-    from sila2.pb2_stubs import SiLAFramework_pb2
-    from sila2.pb2_stubs.SiLAFramework_pb2 import ExecutionInfo as SilaExecutionInfo
+from sila2.framework.pb2 import SiLAFramework_pb2
+from sila2.framework.pb2.SiLAFramework_pb2 import ExecutionInfo as SilaExecutionInfo
 
 
 class ExecutionInfo(MessageMappable):
@@ -22,7 +20,6 @@ class ExecutionInfo(MessageMappable):
         self.message_type = silaframework_pb2_module.ExecutionInfo
         self.__real_field = Real(silaframework_pb2_module)
         self.__duration_field = Duration(silaframework_pb2_module)
-        self.native_type = CommandExecutionInfo
 
     def to_native_type(
         self, message: SilaExecutionInfo, toplevel_named_data_node: Optional[NamedDataNode] = None
